@@ -39,7 +39,7 @@
 #include "variables.h"
 #include "externs.h"
 
-extern int glob_ignore_case, match_ignore_case;
+extern int glob_ignore_case;
 
 int
 sh_regmatch (string, pattern, flags)
@@ -57,14 +57,15 @@ sh_regmatch (string, pattern, flags)
   char *subexp_str;
   int subexp_len;
 #endif
-  int result;
+  int result;  
+
 
 #if defined (ARRAY_VARS)
   rematch = (SHELL_VAR *)NULL;
 #endif
   
   rflags = REG_EXTENDED;
-  if (glob_ignore_case || match_ignore_case)
+  if (glob_ignore_case)
     rflags |= REG_ICASE;
 #if !defined (ARRAY_VARS)
   rflags |= REG_NOSUB;
