@@ -1,6 +1,6 @@
 /* mailcheck.c -- The check is in the mail... */
 
-/* Copyright (C) 1987-2004 Free Software Foundation, Inc.
+/* Copyright (C) 1987-2002 Free Software Foundation, Inc.
 
 This file is part of GNU Bash, the Bourne Again SHell.
 
@@ -122,15 +122,6 @@ find_mail_file (file)
     } \
   while (0)
 
-#define UPDATE_MAIL_FILE(i, finfo) \
-  do \
-    { \
-      mailfiles[i]->access_time = finfo.st_atime; \
-      mailfiles[i]->mod_time = finfo.st_mtime; \
-      mailfiles[i]->file_size = finfo.st_size; \
-    } \
-  while (0)
-
 static void
 update_mail_file (i)
      int i;
@@ -140,7 +131,11 @@ update_mail_file (i)
 
   file = mailfiles[i]->name;
   if (mailstat (file, &finfo) == 0)
-    UPDATE_MAIL_FILE (i, finfo);
+    {
+      mailfiles[i]->access_time = finfo.st_atime;
+      mailfiles[i]->mod_time = finfo.st_mtime;
+      mailfiles[i]->file_size = finfo.st_size;
+    }
   else
     RESET_MAIL_FILE (i);
 }
@@ -160,8 +155,11 @@ add_mail_file (file, msg)
   if (i >= 0)
     {
       if (mailstat (filename, &finfo) == 0)
-	UPDATE_MAIL_FILE (i, finfo);
-
+	{
+	  mailfiles[i]->mod_time = finfo.st_mtime;
+	  mailfiles[i]->access_time = finfo.st_atime;
+	  mailfiles[i]->file_size = finfo.st_size;
+	}
       free (filename);
       return i;
     }
@@ -184,7 +182,9 @@ reset_mail_files ()
   register int i;
 
   for (i = 0; i < mailfiles_count; i++)
-    RESET_MAIL_FILE (i);
+    {
+      RESET_MAIL_FILE (i);
+    }
 }
 
 /* Free the information that we have about the remembered mail files. */
@@ -208,8 +208,7 @@ free_mail_files ()
 }
 
 /* Return non-zero if FILE's mod date has changed and it has not been
-   accessed since modified.  If the size has dropped to zero, reset
-   the cached mail file info. */
+   accessed since modified. */
 static int
 file_mod_date_changed (i)
      int i;
@@ -224,9 +223,6 @@ file_mod_date_changed (i)
   if ((mailstat (file, &finfo) == 0) && (finfo.st_size > 0))
     return (mtime != finfo.st_mtime);
 
-  if (finfo.st_size == 0 && mailfiles[i]->file_size > 0)
-    UPDATE_MAIL_FILE (i, finfo);
-
   return (0);
 }
 
@@ -385,7 +381,7 @@ check_mail ()
 	  use_user_notification = mailfiles[i]->msg != (char *)NULL;
 	  message = mailfiles[i]->msg ? mailfiles[i]->msg : _("You have mail in $_");
 
-	  bind_variable ("_", current_mail_file, 0);
+	  bind_variable ("_", current_mail_file);
 
 #define atime mailfiles[i]->access_time
 #define mtime mailfiles[i]->mod_time
@@ -430,7 +426,7 @@ check_mail ()
 
   if (dollar_underscore)
     {
-      bind_variable ("_", dollar_underscore, 0);
+      bind_variable ("_", dollar_underscore);
       free (dollar_underscore);
     }
   else
